"""scrappi - EO Satellite product catalogue retrieval by API or file system"""

__author__ = "Sam Hunt <sam.hunt@npl.co.uk>"
__all__ = []

from ._version import get_versions

__version__ = get_versions()["version"]
del get_versions



"""Sample unit tests"""

import pytest


def test_pass():
    assert True, "dummy sample test"


@pytest.mark.slow
def test_slow():
    print("This is a very slow test which will sometimes be skipped (see the readme)")
    assert True



"""describe class"""

"""___Built-In Modules___"""
#import here

"""___Third-Party Modules___"""
#import here

"""___NPL Modules___"""
#import here

"""___Authorship___"""
__author__ = "Pieter De Vis"
__created__ = "01/02/2021"
__maintainer__ = "Pieter De Vis"
__email__ = "pieter.de.vis@npl.co.uk"
__status__ = "Development"


class ClassName:
    def __init__(
        self,
        something
    ):
        self.something = something

    def function1(self, argument1, argument2):
        return argument1+argument2
        


"""Tests for classname module"""

"""___Built-In Modules___"""
#import here

"""___Third-Party Modules___"""
import unittest

"""___NPL Modules___"""
#import here

"""___Authorship___"""
__author__ = "Pieter De Vis"
__created__ = "01/02/2021"
__maintainer__ = "Pieter De Vis"
__email__ = "pieter.de.vis@npl.co.uk"
__status__ = "Development"


class TestClassName(unittest.TestCase):
    def test_function1(self):
        pass

if __name__ == "__main__":
    unittest.main()
        